
 ## instagramy
 [![PyPI](https://img.shields.io/pypi/v/instagramy.svg)](https://pypi.org/project/instagramy/)</br>
  Get Instagram users informations
  ## Download:
  #### Windows:
  <code>pip install instagramy</code>
  #### Linux:
  <code>pip3 install instagramy</code>
  ## Usage:
  <code>from instagram import Instagram </code> <br/>
  <code>name = Instagram("virat.kohli")</code> <br />
  <code>popularity = name.popularity()</code><br />
  <code>posts = name.get_posts_details()</code> <br />
  <code>profile = name.get_profile_pic()</code> <br />
  <code>bio = name.get_biography()</code>
  ## Samples:
  ![sample image](https://github.com/yogeshwaran01/instagramy/blob/master/samples/instagramy.png?raw=true)
  ![sample image](https://github.com/yogeshwaran01/instagramy/blob/master/samples/instagramy(1).png?raw=true)
  #### to get posts details as lists of dictionary:
  ![sample image](https://github.com/yogeshwaran01/instagramy/blob/master/samples/ins.png?raw=true)
   ## Source code to download dp:
   [Link to download dp(Source code)](https://gist.github.com/yogeshwaran01/7e506f85990ff6de48466833ef86c4db)
